@@ -6,18 +6,19 @@
 #' @description 
 #' \code{h_academie} gives access to the Academie francaise's dictionary.
 #' 
+#' \code{h_etz} gives access to the EveryTimeZone website.
+#' 
 #' \code{h_framasoft} gives access to several free web services (as in speech and in 
 #' half pint of beer) that are good alternatives to GAFA services. 
 #' 
 #' \code{h_lexilogos} gives access to hundreds of dictionaries in many languages.
 #' 
-#' \code{h_linguee} gives access to a translation engine in many languages. Many
-#' examples with long sentences.
+#' \code{h_googletranslate}, \code{h_interglot}, \code{h_reverso}, \code{h_linguee}, 
+#' \code{h_promt}, \code{h_reverso}, \code{h_systran} provide translation engines. 
+#' \code{h_linguee} returns examples with long sentences.
 #' 
-#' \code{h_reverso} gives access to a translation engine and dictionnaries in many languages.
-#' 
-#' \code{h_tad} and \code{h_tadsm} gives access to a website dedicated to date and time 
-#' conversion plus timezone management.
+#' \code{h_tad} and \code{h_tadsm} gives access to a website dedicated to date 
+#' and time conversion plus timezone management.
 #' 
 #' \code{h_yacy} is a decentralized peer-to-peer web search software.
 #' 
@@ -39,6 +40,13 @@ h_academie <- function() {
 utils::browseURL("https://www.dictionnaire-academie.fr")
 }
 
+#' @export
+#' @rdname h_direct
+h_etz <- function() {
+    message("Open EveryTimeZone in browser")
+utils::browseURL("https://everytimezone.com")
+}
+
 #' @export
 #' @rdname h_direct
 h_framasoft <- function() {
@@ -53,6 +61,20 @@ h_framasoft0 <- function() {
 utils::browseURL("https://framasoft.org/en/")
 }
 
+#' @export
+#' @rdname h_direct
+h_googletranslate <- function() {
+    message("Open Google Translate in browser")
+utils::browseURL("https://translate.google.com")
+}
+
+#' @export
+#' @rdname h_direct
+h_interglot <- function() {
+    message("Open Interglot translation services in browser")
+utils::browseURL("https://www.interglot.com/dictionary")
+}
+
 #' @export
 #' @rdname h_direct
 h_lexilogos <- function() {
@@ -67,6 +89,13 @@ h_linguee <- function() {
 utils::browseURL("https://www.linguee.com")
 }
 
+#' @export
+#' @rdname h_direct
+h_promt <- function() {
+    message("Open PROMT online-translator in browser")
+utils::browseURL("https://www.online-translator.com")
+}
+
 #' @export
 #' @rdname h_direct
 h_reverso <- function() {
@@ -74,6 +103,13 @@ h_reverso <- function() {
 utils::browseURL("http://www.reverso.net/text_translation.aspx?lang=FR")
 }
 
+#' @export
+#' @rdname h_direct
+h_systran <- function() {
+    message("Open Systran translation services in browser")
+utils::browseURL("https://translate.systran.net/translationTools/text")
+}
+
 #' @export
 #' @rdname h_direct
 h_tad <- function() {
