@@ -57,17 +57,17 @@
 #' \donttest{
 #' ## Generate a txt file
 #' p_text(vec, filename = "SearchFind.txt", dir = file.path(tempdir(), "ptext"), 
-#'        repos = "https://cran.univ-paris1.fr") 
+#'        repos = "https://cloud.r-project.org") 
 #' 
 #' ## Generate a markdown file (and use rmarkdown::render() for further treatment)
 #' ## In sep1, replace the '=' sign by the sharp sign (rejected by R CMD check)
 #' p_text(char = lst, filename = "Chemistry.md", beforetext = funheadermd(), 
 #'        f_maintext = funmaintext, sep1 = "= ", sep2 = "  ", 
-#'        dir = file.path(tempdir(), "ptext"), repos = "https://cran.univ-paris1.fr") 
+#'        dir = file.path(tempdir(), "ptext"), repos = "https://cloud.r-project.org") 
 #' 
 #' ## Generate 4 tex + 4 pdf files (40-60 seconds)
 #' p_text2pdf(lst, dir = file.path(tempdir(), "ptext"), cleantex = FALSE, 
-#'           openpdf = FALSE, repos = "https://cran.univ-paris1.fr") 
+#'           openpdf = FALSE, repos = "https://cloud.r-project.org") 
 #' }
 #' @name p_text2pdf
 NULL
@@ -219,21 +219,41 @@ if (verbose) vecfiles2 else invisible(vecfiles2)
 
 
 
-
+## (v-4.6.5) REPLACE BRUTE FORCE p_texth, funreadme, funnews, funvignettes
+## WITH xml PARSING => XML::getHTMLLinks(doc)
 
 p_texth <- function(pkgs, filename, beforetext, f_maintext, sep1, sep2, eol, 
-                   README, NEWS, vignettes, aftertext, crandb, repos) {
-    con <- file(filename, open = "w+", encoding = "UTF-8")
+                    README, NEWS, vignettes, aftertext, crandb, repos) {
+	eollatex <- grepl("\\\\", eol, fixed = TRUE)
+	con <- file(filename, open = "w+", encoding = "UTF-8")
     if (beforetext != "") writeLines(enc2utf8(beforetext), con = con)
     for (pkg in pkgs) {
+		iurl    <- file.path(repos, "web", "packages", pkg, "index.html")
+		purl    <- file.path(repos, "web", "packages", pkg)
+		doc     <- tempfile()
+		trd     <- trydownloadurl(iurl, doc)
+		links   <- if (trd == 0) XML::getHTMLLinks(doc) else " "
+		txtrme  <- grep("readme", links, ignore.case = TRUE, value = TRUE)[1]
+		txtrme  <- grep("ReadMe", txtrme, ignore.case = FALSE, value = TRUE, invert = TRUE)[1]
+		txtnews <- grep("NEWS", links, ignore.case = TRUE, value = TRUE)[1]
+		txtvig  <- grep("vignettes", links, ignore.case = TRUE, value = TRUE)
+		if (!is.na(txtrme[1])) {
+			txtrme  <- file.path(purl, txtrme)
+			if (eollatex) txtrme <- paste0("\\url{", txtrme, "}")
+		}
+		if (!is.na(txtnews[1])) {
+			txtnews <- file.path(purl, txtnews) 
+			if (eollatex) txtnews <- paste0("\\url{", txtnews, "}")
+		}
+		if (!is.na(txtvig[1])) {
+			txtvig  <- file.path(purl, txtvig)
+			if (eollatex) txtvig <- paste0("\\url{", txtvig, "}")
+		}		
         txtpky  <- f_maintext(pkg, sep1, sep2, eol, crandb, repos)
-        txtrme  <- funreadme(pkg, repos, eol)
-        txtnews <- funnews(pkg, repos, eol)
-        txtvig  <- funvignettes(pkg, repos, eol)
         writeLines(txtpky, con = con, sep = eol)
-        if (README & nzchar(txtrme[1]))    writeLines(txtrme,  con = con, sep = eol)
-        if (NEWS  & nzchar(txtnews[1]))    writeLines(txtnews, con = con, sep = eol)
-        if (vignettes & nzchar(txtvig[1])) writeLines(txtvig,  con = con, sep = eol)
+        if (README && !is.na(txtrme[1]))    writeLines(txtrme,  con = con, sep = eol)
+        if (NEWS  && !is.na(txtnews[1]))    writeLines(txtnews, con = con, sep = eol)
+        if (vignettes && !is.na(txtvig[1])) writeLines(txtvig,  con = con, sep = eol)
         close_libcurl()
     }
     writeLines("\n", con = con)
